@@ -6,7 +6,8 @@ import numpy as np
 import datetime
 from geopy.geocoders import Nominatim
 from datetime import timedelta
-import time
+from datetime import datetime
+
 
 def earthquake_distance(place):    
 
@@ -30,7 +31,7 @@ def earthquake_distance(place):
     city = place
     loc = geolocator.geocode(city)
 
-    today = datetime.datetime.today()
+    today = datetime.today()
     yesterday = today - timedelta(days=1)
     today = today.strftime('%Y-%m-%d')
     yesterday = yesterday.strftime('%Y-%m-%d')
@@ -120,7 +121,7 @@ def earthquake_longitude(place):
     city = place
     loc = geolocator.geocode(city)
 
-    today = datetime.datetime.today()
+    today = datetime.today()
     yesterday = today - timedelta(days=1)
     today = today.strftime('%Y-%m-%d')
     yesterday = yesterday.strftime('%Y-%m-%d')
@@ -208,7 +209,7 @@ def earthquake_latitude(place):
     city = place
     loc = geolocator.geocode(city)
 
-    today = datetime.datetime.today()
+    today = datetime.today()
     yesterday = today - timedelta(days=1)
     today = today.strftime('%Y-%m-%d')
     yesterday = yesterday.strftime('%Y-%m-%d')
@@ -296,7 +297,7 @@ def earthquake_magnitude(place):
     city = place
     loc = geolocator.geocode(city)
 
-    today = datetime.datetime.today()
+    today = datetime.today()
     yesterday = today - timedelta(days=1)
     today = today.strftime('%Y-%m-%d')
     yesterday = yesterday.strftime('%Y-%m-%d')
@@ -383,7 +384,7 @@ def earthquake_place(place):
     city = place
     loc = geolocator.geocode(city)
 
-    today = datetime.datetime.today()
+    today = datetime.today()
     yesterday = today - timedelta(days=1)
     today = today.strftime('%Y-%m-%d')
     yesterday = yesterday.strftime('%Y-%m-%d')
@@ -472,7 +473,7 @@ def earthquake_time(place):
     city = place
     loc = geolocator.geocode(city)
 
-    today = datetime.datetime.today()
+    today = datetime.today()
     yesterday = today - timedelta(days=1)
     today = today.strftime('%Y-%m-%d')
     yesterday = yesterday.strftime('%Y-%m-%d')
@@ -534,11 +535,17 @@ def earthquake_time(place):
     time_v = all["time"].iloc[0]
     # can also return df as dataframe
 
-
-    timestamp = time_v
-    dt_obj = datetime.fromtimestamp(timestamp / 1000).strftime('%d-%m-%y')
+    ts = int(time_v) / 1000
+    abc = datetime.utcfromtimestamp(ts).strftime('%Y-%m-%d %H:%M:%S')
+    #dt_obj = datetime..strftime('%d-%m-%y')
     
-    return dt_obj
+    return abc
+
+
+
+
+
+
 
 def earthquake_df(place):    
 
@@ -562,7 +569,7 @@ def earthquake_df(place):
     city = place
     loc = geolocator.geocode(city)
 
-    today = datetime.datetime.today()
+    today = datetime.today()
     yesterday = today - timedelta(days=1)
     today = today.strftime('%Y-%m-%d')
     yesterday = yesterday.strftime('%Y-%m-%d')
@@ -599,7 +606,12 @@ def earthquake_df(place):
         latlist.append(latitude)
         magnitudelist.append(magnitude)
         placelist.append(place)
-        timelist.append(time)
+        
+        
+        ts = int(time) / 1000
+        abc = datetime.utcfromtimestamp(ts).strftime('%Y-%m-%d %H:%M:%S')
+                
+        timelist.append(abc)
         distance_from_earthquake.append(distance)
 
     d = {'longitude':longlist,'latitude':latlist,'distance':distance_from_earthquake,'magnitude': magnitudelist,'place': placelist,'time': timelist }
@@ -626,3 +638,99 @@ def earthquake_df(place):
     
     return df
 
+
+def earthquake_less_than(place,less_than):    
+
+
+    #https://towardsdatascience.com/heres-how-to-calculate-distance-between-2-geolocations-in-python-93ecab5bbba4
+
+    def haversine_distance(lat1, lon1, lat2, lon2):
+       r = 6371
+       phi1 = np.radians(lat1)
+       phi2 = np.radians(lat2)
+       delta_phi = np.radians(lat2 - lat1)
+       delta_lambda = np.radians(lon2 - lon1)
+       a = np.sin(delta_phi / 2)**2 + np.cos(phi1) * np.cos(phi2) *   np.sin(delta_lambda / 2)**2
+       res = r * (2 * np.arctan2(np.sqrt(a), np.sqrt(1 - a)))
+       return np.round(res, 2)
+
+
+    #https://stackoverflow.com/questions/25888396/how-to-get-latitude-longitude-with-python
+    
+    geolocator = Nominatim(user_agent="my_user_agent")
+    city = place
+    loc = geolocator.geocode(city)
+
+    today = datetime.today()
+    yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
+
+    
+
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
+    data = json.loads(json_url.read())
+
+    json_dict = data.get('features')
+
+
+    latlist = []
+    longlist = []
+    magnitudelist = []
+    placelist = []
+    timelist = []
+    distance_from_earthquake = []
+
+    for row in json_dict:
+        ab = row['geometry']
+        rd = ab.get('coordinates')
+        ac = row['properties']
+        re = ac.get('mag')
+        rf = ac.get('place')
+        rg = ac.get('time')
+        longitude = rd[0]
+        latitude = rd[1]
+        magnitude = re
+        place = rf
+        time = rg
+        distance = haversine_distance(latitude, longitude, loc.latitude, loc.longitude)
+        longlist.append(longitude)
+        latlist.append(latitude)
+        magnitudelist.append(magnitude)
+        placelist.append(place)
+        
+        
+        ts = int(time) / 1000
+        abc = datetime.utcfromtimestamp(ts).strftime('%Y-%m-%d %H:%M:%S')
+                
+        timelist.append(abc)
+        distance_from_earthquake.append(distance)
+
+    d = {'longitude':longlist,'latitude':latlist,'distance':distance_from_earthquake,'magnitude': magnitudelist,'place': placelist,'time': timelist }
+
+    #turned the dictionary into a pandas dataframe
+    df = pd.DataFrame(d)
+    
+
+    column = df["distance"]
+    min_value = column.min()
+    
+    all = df.loc[df['distance'] == min_value]
+    
+    
+    
+    
+    longitude_v = all["longitude"].iloc[0]
+    latitude_v = all["latitude"].iloc[0]
+    distance_v = all["distance"].iloc[0]
+    magnitude_v = all["magnitude"].iloc[0]
+    place_v = all["place"].iloc[0]
+    time_v = all["time"].iloc[0]
+    # can also return df as dataframe
+    
+    rslt_df = df[df['distance'] < less_than]
+    rslt_df = rslt_df.sort_values(by=['distance'])
+    
+    return rslt_df
+
+
